# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['yar_numerals',
 'yar_numerals.lexeme',
 'yar_numerals.lexeme.numeral',
 'yar_numerals.syntax']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'yar-numerals',
    'version': '1.0.0',
    'description': 'Number to text - Inflector for Ukrainian numerals',
    'long_description': '# Ukrainian Numbers Spellout\n\nThis library allows to convert the numbers into numerals\n\n## Supported Features\n\n- [x] Number spellout – converting numbers into text (numerals)\n- [x] Numeral inflection - modifying grammatical form of numerals to match required grammatical characteristics\n- [x] Agreement - setting grammatical forms of compound numerals to produce grammatically and syntactically correct text\n- [x] Stress\n- [x] Cardinal numbers in range [0...1×10<sup>27</sup>)<sup>_1_, _2_</sup>\n- [x] Ordinal numbers in range [0...1×10<sup>27</sup>)<sup>_1_</sup>\n- [x] Fractional numbers with whole, each element in range [0...1×10<sup>27</sup>)\n- [x] Decimal numbers in range (0...1×10<sup>27</sup>) with precision up to 1×10<sup>-27</sup> <sup>_3_</sup>\n\n---\n\n<sup>_1_</sup> Numbers outside of the range will be spelled out digit-wise and inflected only last digit\n\n<sup>_2_</sup> 1×10<sup>27</sup> is 1 000 000 000 000 000 000 000 000 000\n\n<sup>_3_</sup> 1×10<sup>-27</sup> is 0.000 000 000 000 000 000 000 000 001\n\n## Future Features\n\n- [ ] Negative numbers\n- [ ] Contracted ordinal numbers (e.g. "1-й", "1000-на")\n- [ ] Scientific notation of exponential numbers (e.g. "1e5")\n\n## Supported Grammatical Attributes\n\n- cases: nominative, genitive, dative, accusative, instrumental, locative, vocative\n- gender: masculine, feminine, neuter\n- number: singular, plural\n- animacy: inanimate, animate\n',
    'author': 'Yar team',
    'author_email': 'team@yar.org.ua',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://yar.org.ua/',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.7,<3.12',
}


setup(**setup_kwargs)



import pytest
from .fractionals import inflect
from .errors import RangeError

# fmt: off
simple_map = {
    "nom": ("case", "nominative"),
    "gen": ("case", "genitive"),
    "dat": ("case", "dative"),
    "acc": ("case", "accusative"),
    "inst": ("case", "instrumental"),
    "loc": ("case", "locative"),
    "voc": ("case", "vocative"),
    "m": ("gender", "masculine"),
    "f": ("gender", "feminine"),
    "n": ("gender", "neuter"),
    "sg": ("number", "singular"),
    "pl": ("number", "plural"),
    "card": ("type", "cardinal"),
    "ord": ("type", "ordinal"),
    "inan": ("animacy", "inanimate"),
    "anim": ("animacy", "animate"),
}


def fm(s):
    return {simple_map[g][0]: simple_map[g][1] for g in s.split(";")}


# def test_0():
#     assert inflect("0", "0" fm("m")) == "нульови́й"
#     assert inflect("0", fm("f")) == "нульова́"
#     assert inflect("0", fm("n")) == "нульове́"
#     assert inflect("0", fm("gen")) == "нульово́го"
#     assert inflect("0", fm("gen;f")) == "нульово́ї"
#     assert inflect("0", fm("acc;f;anim")) == "нульову́"
#     assert inflect("0", fm("acc;f;inan")) == "нульову́"
#     assert inflect("0", fm("loc;f")) == "нульові́й"


def test_gov_agreement():
    assert inflect("", "1", "1", fm("m")) == "одна́ пе́рша"
    assert inflect("", "2", "1", fm("m")) == "дві́ пе́рших"
    assert inflect("", "3", "1", fm("m")) == "три́ пе́рших"
    assert inflect("", "5", "1", fm("m")) == "пʼя́ть пе́рших"
    assert inflect("", "0", "1", fm("m")) == "ну́ль пе́рших"

def test_1_2():
    assert inflect("", "1", "2", fm("m")) == "одна́ дру́га"
    assert inflect("", "1", "2", fm("gen;m")) == "одніє́ї дру́гої"
    assert inflect("", "1", "2", fm("acc;m")) == "одну́ дру́гу"
    assert inflect("", "1", "2", fm("dat;m")) == "одні́й дру́гій"
    assert inflect("", "1", "2", fm("inst;m")) == "одніє́ю дру́гою"
    assert inflect("", "1", "2", fm("loc;m")) == "одні́й дру́гій"
    assert inflect("", "1", "2", fm("voc;m")) == "одна́ дру́га"

def test_40_143():
    assert inflect("", "40", "143", fm("m")) == "со́рок сто́ со́рок тре́тіх"

def test_1_1_2():
    assert inflect("1", "1", "2", fm("m")) == "одна́ ці́ла одна́ дру́га"
    assert inflect("1", "1", "2", fm("m;gen")) == "одніє́ї ці́лої одніє́ї дру́гої"

def test_1002_1003():
    assert inflect("", "1002", "1003", fm("nom;m")) == "ти́сяча дві́ ти́сяча тре́тіх"
    assert inflect("", "1002", "1003", fm("acc;m")) == "ти́сячу дві́ ти́сяча тре́тіх"

def test_1001_1002_1003():
    assert inflect("1001", "1002", "1003", fm("nom;m")) == "ти́сяча одна́ ці́ла ти́сяча дві́ ти́сяча тре́тіх"
    assert inflect("1001", "1002", "1003", fm("acc;m")) == "ти́сячу одну́ ці́лу ти́сячу дві́ ти́сяча тре́тіх"

def test_cases_sg():
    assert inflect("", "1", "3", fm("nom")) == "одна́ тре́тя" # частина
    assert inflect("", "1", "3", fm("gen")) == "одніє́ї тре́тьої" # частини
    assert inflect("", "1", "3", fm("dat")) == "одні́й тре́тій" # частині
    assert inflect("", "1", "3", fm("acc")) == "одну́ тре́тю" # частину
    assert inflect("", "1", "3", fm("inst")) == "одніє́ю тре́тьою" # частиною
    assert inflect("", "1", "3", fm("loc")) == "одні́й тре́тій" # частині
    assert inflect("", "1", "3", fm("voc")) == "одна́ тре́тя" # частино

def test_cases_pс():
    assert inflect("", "2", "3", fm("nom")) == "дві́ тре́тіх" # частини
    assert inflect("", "2", "3", fm("gen")) == "дво́х тре́тіх" # частин
    assert inflect("", "2", "3", fm("dat")) == "дво́м тре́тім" # частинам
    assert inflect("", "2", "3", fm("acc")) == "дві́ тре́тіх" # частини
    assert inflect("", "2", "3", fm("inst")) == "двома́ тре́тіми" # частинами
    assert inflect("", "2", "3", fm("loc")) == "дво́х тре́тіх" # частинах

def test_cases_pl():
    assert inflect("", "5", "3", fm("nom")) == "пʼя́ть тре́тіх" # частин
    assert inflect("", "5", "3", fm("gen")) == "пʼяти́ тре́тіх" # частин
    assert inflect("", "5", "3", fm("dat")) == "пʼяти́ тре́тім" # частинам
    assert inflect("", "5", "3", fm("acc")) == "пʼя́ть тре́тіх" # частин
    assert inflect("", "5", "3", fm("inst")) == "пʼятьма́ тре́тіми" # частинами
    assert inflect("", "5", "3", fm("loc")) == "пʼяти́ тре́тіх" # частинах



# (c) Copyright by Yar.
#
# Source file generated automatically.
# fmt: off


data = {
  "1": ([
    (dict(case="nominative", gender="masculine"), "оди́н"),
    (dict(case="nominative", gender="feminine"), "одна́"),
    (dict(case="nominative", gender="neuter"), "одне́"),
    (dict(case="nominative", gender="neuter"), "одно́"),
    (dict(case="genitive", gender="masculine"), "одного́"),
    (dict(case="genitive", gender="feminine"), "одніє́ї"),
    (dict(case="genitive", gender="feminine"), "одно́ї"),
    (dict(case="genitive", gender="neuter"), "одного́"),
    (dict(case="dative", gender="masculine"), "одному́"),
    (dict(case="dative", gender="feminine"), "одні́й"),
    (dict(case="dative", gender="neuter"), "одному́"),
    (dict(case="accusative", gender="masculine", animacy="inanimate"), "оди́н"),
    (dict(case="accusative", gender="masculine", animacy="animate"), "одного́"),
    (dict(case="accusative", gender="feminine"), "одну́"),
    (dict(case="accusative", gender="neuter"), "одне́"),
    (dict(case="instrumental", gender="masculine"), "одни́м"),
    (dict(case="instrumental", gender="feminine"), "одніє́ю"),
    (dict(case="instrumental", gender="feminine"), "одно́ю"),
    (dict(case="instrumental", gender="neuter"), "одни́м"),
    (dict(case="locative", gender="masculine"), "одному́"),
    (dict(case="locative", gender="masculine"), "одні́м"),
    (dict(case="locative", gender="feminine"), "одні́й"),
    (dict(case="locative", gender="neuter"), "одному́"),
    (dict(case="locative", gender="neuter"), "одні́м"),
    (dict(case="vocative", gender="masculine"), "оди́н"),
    (dict(case="vocative", gender="feminine"), "одна́"),
    (dict(case="vocative", gender="neuter"), "одне́"),
  ], dict()),
  "2": ([
    (dict(case="nominative", gender="masculine"), "два́"),
    (dict(case="nominative", gender="feminine"), "дві́"),
    (dict(case="nominative", gender="neuter"), "два́"),
    (dict(case="genitive"), "дво́х"),
    (dict(case="dative"), "дво́м"),
    (dict(case="accusative", gender="masculine", animacy="inanimate"), "два́"),
    (dict(case="accusative", gender="masculine", animacy="animate"), "дво́х"),
    (dict(case="accusative", gender="feminine", animacy="inanimate"), "дві́"),
    (dict(case="accusative", gender="feminine", animacy="animate"), "дво́х"),
    (dict(case="accusative", gender="neuter", animacy="inanimate"), "два́"),
    (dict(case="accusative", gender="neuter", animacy="animate"), "дво́х"),
    (dict(case="instrumental"), "двома́"),
    (dict(case="locative"), "дво́х"),
    (dict(case="vocative", gender="masculine"), "два́"),
    (dict(case="vocative", gender="feminine"), "дві́"),
    (dict(case="vocative", gender="neuter"), "два́"),
  ], dict()),
  "3": ([
    (dict(case="nominative"), "три́"),
    (dict(case="genitive"), "трьо́х"),
    (dict(case="dative"), "трьо́м"),
    (dict(case="accusative", animacy="inanimate"), "три́"),
    (dict(case="accusative", animacy="animate"), "трьо́х"),
    (dict(case="instrumental"), "трьома́"),
    (dict(case="locative"), "трьо́х"),
    (dict(case="vocative"), "три́"),
  ], dict()),
  "4": ([
    (dict(case="nominative"), "чоти́ри"),
    (dict(case="genitive"), "чотирьо́х"),
    (dict(case="dative"), "чотирьо́м"),
    (dict(case="accusative", animacy="inanimate"), "чоти́ри"),
    (dict(case="accusative", animacy="animate"), "чотирьо́х"),
    (dict(case="instrumental"), "чотирма́"),
    (dict(case="locative"), "чотирьо́х"),
    (dict(case="vocative"), "чоти́ри"),
  ], dict()),
  "5": ([
    (dict(case="nominative"), "пʼя́ть"),
    (dict(case="genitive"), "пʼяти́"),
    (dict(case="genitive"), "пʼятьо́х"),
    (dict(case="dative"), "пʼяти́"),
    (dict(case="dative"), "пʼятьо́м"),
    (dict(case="accusative", animacy="inanimate"), "пʼя́ть"),
    (dict(case="accusative", animacy="animate"), "пʼятьо́х"),
    (dict(case="instrumental"), "пʼятьма́"),
    (dict(case="instrumental"), "пʼятьома́"),
    (dict(case="locative"), "пʼяти́"),
    (dict(case="locative"), "пʼятьо́х"),
    (dict(case="vocative"), "пʼя́ть"),
  ], dict()),
  "6": ([
    (dict(case="nominative"), "ші́сть"),
    (dict(case="genitive"), "шести́"),
    (dict(case="genitive"), "шістьо́х"),
    (dict(case="dative"), "шести́"),
    (dict(case="dative"), "шістьо́м"),
    (dict(case="accusative", animacy="inanimate"), "ші́сть"),
    (dict(case="accusative", animacy="animate"), "шістьо́х"),
    (dict(case="instrumental"), "шістьма́"),
    (dict(case="instrumental"), "шістьома́"),
    (dict(case="locative"), "шести́"),
    (dict(case="locative"), "шістьо́х"),
    (dict(case="vocative"), "ші́сть"),
  ], dict()),
  "7": ([
    (dict(case="nominative"), "сі́м"),
    (dict(case="genitive"), "семи́"),
    (dict(case="genitive"), "сімо́х"),
    (dict(case="dative"), "семи́"),
    (dict(case="dative"), "сімо́м"),
    (dict(case="accusative", animacy="inanimate"), "сі́м"),
    (dict(case="accusative", animacy="animate"), "сімо́х"),
    (dict(case="instrumental"), "сьома́"),
    (dict(case="instrumental"), "сімома́"),
    (dict(case="locative"), "семи́"),
    (dict(case="locative"), "сімо́х"),
    (dict(case="vocative"), "сі́м"),
  ], dict()),
  "8": ([
    (dict(case="nominative"), "ві́сім"),
    (dict(case="genitive"), "восьми́"),
    (dict(case="genitive"), "вісьмо́х"),
    (dict(case="dative"), "восьми́"),
    (dict(case="dative"), "вісьмо́м"),
    (dict(case="accusative", animacy="inanimate"), "ві́сім"),
    (dict(case="accusative", animacy="animate"), "вісьмо́х"),
    (dict(case="instrumental"), "вісьма́"),
    (dict(case="instrumental"), "вісьмома́"),
    (dict(case="locative"), "восьми́"),
    (dict(case="locative"), "вісьмо́х"),
    (dict(case="vocative"), "ві́сім"),
  ], dict()),
  "9": ([
    (dict(case="nominative"), "де́вʼять"),
    (dict(case="genitive"), "девʼяти́"),
    (dict(case="genitive"), "девʼятьо́х"),
    (dict(case="dative"), "девʼяти́"),
    (dict(case="dative"), "девʼятьо́м"),
    (dict(case="accusative", animacy="inanimate"), "де́вʼять"),
    (dict(case="accusative", animacy="animate"), "девʼятьо́х"),
    (dict(case="instrumental"), "девʼятьма́"),
    (dict(case="instrumental"), "девʼятьома́"),
    (dict(case="locative"), "девʼяти́"),
    (dict(case="locative"), "девʼятьо́х"),
    (dict(case="vocative"), "де́вʼять"),
  ], dict()),
  "10": ([
    (dict(case="nominative"), "де́сять"),
    (dict(case="genitive"), "десяти́"),
    (dict(case="genitive"), "десятьо́х"),
    (dict(case="dative"), "десяти́"),
    (dict(case="dative"), "десятьо́м"),
    (dict(case="accusative", animacy="inanimate"), "де́сять"),
    (dict(case="accusative", animacy="animate"), "десятьо́х"),
    (dict(case="instrumental"), "десятьма́"),
    (dict(case="instrumental"), "десятьома́"),
    (dict(case="locative"), "десяти́"),
    (dict(case="locative"), "десятьо́х"),
    (dict(case="vocative"), "де́сять"),
  ], dict()),
  "11": ([
    (dict(case="nominative"), "одина́дцять"),
    (dict(case="genitive"), "одинадцяти́"),
    (dict(case="genitive"), "одинадцятьо́х"),
    (dict(case="dative"), "одинадцяти́"),
    (dict(case="dative"), "одинадцятьо́м"),
    (dict(case="accusative", animacy="inanimate"), "одина́дцять"),
    (dict(case="accusative", animacy="animate"), "одинадцятьо́х"),
    (dict(case="instrumental"), "одинадцятьма́"),
    (dict(case="instrumental"), "одинадцятьома́"),
    (dict(case="locative"), "одинадцяти́"),
    (dict(case="locative"), "одинадцятьо́х"),
    (dict(case="vocative"), "одина́дцять"),
  ], dict()),
  "12": ([
    (dict(case="nominative"), "двана́дцять"),
    (dict(case="genitive"), "дванадцяти́"),
    (dict(case="genitive"), "дванадцятьо́х"),
    (dict(case="dative"), "дванадцяти́"),
    (dict(case="dative"), "дванадцятьо́м"),
    (dict(case="accusative", animacy="inanimate"), "двана́дцять"),
    (dict(case="accusative", animacy="animate"), "дванадцятьо́х"),
    (dict(case="instrumental"), "дванадцятьма́"),
    (dict(case="instrumental"), "дванадцятьома́"),
    (dict(case="locative"), "дванадцяти́"),
    (dict(case="locative"), "дванадцятьо́х"),
    (dict(case="vocative"), "двана́дцять"),
  ], dict()),
  "13": ([
    (dict(case="nominative"), "трина́дцять"),
    (dict(case="genitive"), "тринадцяти́"),
    (dict(case="genitive"), "тринадцятьо́х"),
    (dict(case="dative"), "тринадцяти́"),
    (dict(case="dative"), "тринадцятьо́м"),
    (dict(case="accusative", animacy="inanimate"), "трина́дцять"),
    (dict(case="accusative", animacy="animate"), "тринадцятьо́х"),
    (dict(case="instrumental"), "тринадцятьма́"),
    (dict(case="instrumental"), "тринадцятьома́"),
    (dict(case="locative"), "тринадцяти́"),
    (dict(case="locative"), "тринадцятьо́х"),
    (dict(case="vocative"), "трина́дцять"),
  ], dict()),
  "14": ([
    (dict(case="nominative"), "чотирна́дцять"),
    (dict(case="genitive"), "чотирнадцяти́"),
    (dict(case="genitive"), "чотирнадцятьо́х"),
    (dict(case="dative"), "чотирнадцяти́"),
    (dict(case="dative"), "чотирнадцятьо́м"),
    (dict(case="accusative", animacy="inanimate"), "чотирна́дцять"),
    (dict(case="accusative", animacy="animate"), "чотирнадцятьо́х"),
    (dict(case="instrumental"), "чотирнадцятьма́"),
    (dict(case="instrumental"), "чотирнадцятьома́"),
    (dict(case="locative"), "чотирнадцяти́"),
    (dict(case="locative"), "чотирнадцятьо́х"),
    (dict(case="vocative"), "чотирна́дцять"),
  ], dict()),
  "15": ([
    (dict(case="nominative"), "пʼятна́дцять"),
    (dict(case="genitive"), "пʼятнадцяти́"),
    (dict(case="genitive"), "пʼятнадцятьо́х"),
    (dict(case="dative"), "пʼятнадцяти́"),
    (dict(case="dative"), "пʼятнадцятьо́м"),
    (dict(case="accusative", animacy="inanimate"), "пʼятна́дцять"),
    (dict(case="accusative", animacy="animate"), "пʼятнадцятьо́х"),
    (dict(case="instrumental"), "пʼятнадцятьма́"),
    (dict(case="instrumental"), "пʼятнадцятьома́"),
    (dict(case="locative"), "пʼятнадцяти́"),
    (dict(case="locative"), "пʼятнадцятьо́х"),
    (dict(case="vocative"), "пʼятна́дцять"),
  ], dict()),
  "16": ([
    (dict(case="nominative"), "шістна́дцять"),
    (dict(case="genitive"), "шістнадцяти́"),
    (dict(case="genitive"), "шістнадцятьо́х"),
    (dict(case="dative"), "шістнадцяти́"),
    (dict(case="dative"), "шістнадцятьо́м"),
    (dict(case="accusative", animacy="inanimate"), "шістна́дцять"),
    (dict(case="accusative", animacy="animate"), "шістнадцятьо́х"),
    (dict(case="instrumental"), "шістнадцятьма́"),
    (dict(case="instrumental"), "шістнадцятьома́"),
    (dict(case="locative"), "шістнадцяти́"),
    (dict(case="locative"), "шістнадцятьо́х"),
    (dict(case="vocative"), "шістна́дцять"),
  ], dict()),
  "17": ([
    (dict(case="nominative"), "сімна́дцять"),
    (dict(case="genitive"), "сімнадцяти́"),
    (dict(case="genitive"), "сімнадцятьо́х"),
    (dict(case="dative"), "сімнадцяти́"),
    (dict(case="dative"), "сімнадцятьо́м"),
    (dict(case="accusative", animacy="inanimate"), "сімна́дцять"),
    (dict(case="accusative", animacy="animate"), "сімнадцятьо́х"),
    (dict(case="instrumental"), "сімнадцятьма́"),
    (dict(case="instrumental"), "сімнадцятьома́"),
    (dict(case="locative"), "сімнадцяти́"),
    (dict(case="locative"), "сімнадцятьо́х"),
    (dict(case="vocative"), "сімна́дцять"),
  ], dict()),
  "18": ([
    (dict(case="nominative"), "вісімна́дцять"),
    (dict(case="genitive"), "вісімнадцяти́"),
    (dict(case="genitive"), "вісімнадцятьо́х"),
    (dict(case="dative"), "вісімнадцяти́"),
    (dict(case="dative"), "вісімнадцятьо́м"),
    (dict(case="accusative", animacy="inanimate"), "вісімна́дцять"),
    (dict(case="accusative", animacy="animate"), "вісімнадцятьо́х"),
    (dict(case="instrumental"), "вісімнадцятьма́"),
    (dict(case="instrumental"), "вісімнадцятьома́"),
    (dict(case="locative"), "вісімнадцяти́"),
    (dict(case="locative"), "вісімнадцятьо́х"),
    (dict(case="vocative"), "вісімна́дцять"),
  ], dict()),
  "19": ([
    (dict(case="nominative"), "девʼятна́дцять"),
    (dict(case="genitive"), "девʼятнадцяти́"),
    (dict(case="genitive"), "девʼятнадцятьо́х"),
    (dict(case="dative"), "девʼятнадцяти́"),
    (dict(case="dative"), "девʼятнадцятьо́м"),
    (dict(case="accusative", animacy="inanimate"), "девʼятна́дцять"),
    (dict(case="accusative", animacy="animate"), "девʼятнадцятьо́х"),
    (dict(case="instrumental"), "девʼятнадцятьма́"),
    (dict(case="instrumental"), "девʼятнадцятьома́"),
    (dict(case="locative"), "девʼятнадцяти́"),
    (dict(case="locative"), "девʼятнадцятьо́х"),
    (dict(case="vocative"), "девʼятна́дцять"),
  ], dict()),
  "20": ([
    (dict(case="nominative"), "два́дцять"),
    (dict(case="genitive"), "двадцяти́"),
    (dict(case="genitive"), "двадцятьо́х"),
    (dict(case="dative"), "двадцяти́"),
    (dict(case="dative"), "двадцятьо́м"),
    (dict(case="accusative", animacy="inanimate"), "два́дцять"),
    (dict(case="accusative", animacy="animate"), "двадцятьо́х"),
    (dict(case="instrumental"), "двадцятьма́"),
    (dict(case="instrumental"), "двадцятьома́"),
    (dict(case="locative"), "двадцяти́"),
    (dict(case="locative"), "двадцятьо́х"),
    (dict(case="vocative"), "два́дцять"),
  ], dict()),
  "30": ([
    (dict(case="nominative"), "три́дцять"),
    (dict(case="genitive"), "тридцяти́"),
    (dict(case="genitive"), "тридцятьо́х"),
    (dict(case="dative"), "тридцяти́"),
    (dict(case="dative"), "тридцятьо́м"),
    (dict(case="accusative", animacy="inanimate"), "три́дцять"),
    (dict(case="accusative", animacy="animate"), "тридцятьо́х"),
    (dict(case="instrumental"), "тридцятьма́"),
    (dict(case="instrumental"), "тридцятьома́"),
    (dict(case="locative"), "тридцяти́"),
    (dict(case="locative"), "тридцятьо́х"),
    (dict(case="vocative"), "три́дцять"),
  ], dict()),
  "40": ([
    (dict(case="nominative"), "со́рок"),
    (dict(case="genitive"), "сорока́"),
    (dict(case="dative"), "сорока́"),
    (dict(case="accusative"), "со́рок"),
    (dict(case="instrumental"), "сорока́"),
    (dict(case="locative"), "сорока́"),
    (dict(case="vocative"), "со́рок"),
  ], dict()),
  "50": ([
    (dict(case="nominative"), "пʼятдеся́т"),
    (dict(case="genitive"), "пʼятдесяти́"),
    (dict(case="genitive"), "пʼятдесятьо́х"),
    (dict(case="dative"), "пʼятдесяти́"),
    (dict(case="dative"), "пʼятдесятьо́м"),
    (dict(case="accusative", animacy="inanimate"), "пʼятдеся́т"),
    (dict(case="accusative", animacy="animate"), "пʼятдесятьо́х"),
    (dict(case="instrumental"), "пʼятдесятьма́"),
    (dict(case="instrumental"), "пʼятдесятьома́"),
    (dict(case="locative"), "пʼятдесяти́"),
    (dict(case="locative"), "пʼятдесятьо́х"),
    (dict(case="vocative"), "пʼятдеся́т"),
  ], dict()),
  "60": ([
    (dict(case="nominative"), "шістдеся́т"),
    (dict(case="genitive"), "шістдесяти́"),
    (dict(case="genitive"), "шістдесятьо́х"),
    (dict(case="dative"), "шістдесяти́"),
    (dict(case="dative"), "шістдесятьо́м"),
    (dict(case="accusative", animacy="inanimate"), "шістдеся́т"),
    (dict(case="accusative", animacy="animate"), "шістдесятьо́х"),
    (dict(case="instrumental"), "шістдесятьма́"),
    (dict(case="instrumental"), "шістдесятьома́"),
    (dict(case="locative"), "шістдесяти́"),
    (dict(case="locative"), "шістдесятьо́х"),
    (dict(case="vocative"), "шістдеся́т"),
  ], dict()),
  "70": ([
    (dict(case="nominative"), "сімдеся́т"),
    (dict(case="genitive"), "сімдесяти́"),
    (dict(case="genitive"), "сімдесятьо́х"),
    (dict(case="dative"), "сімдесяти́"),
    (dict(case="dative"), "сімдесятьо́м"),
    (dict(case="accusative", animacy="inanimate"), "сімдеся́т"),
    (dict(case="accusative", animacy="animate"), "сімдесятьо́х"),
    (dict(case="instrumental"), "сімдесятьма́"),
    (dict(case="instrumental"), "сімдесятьома́"),
    (dict(case="locative"), "сімдесяти́"),
    (dict(case="locative"), "сімдесятьо́х"),
    (dict(case="vocative"), "сімдеся́т"),
  ], dict()),
  "80": ([
    (dict(case="nominative"), "вісімдеся́т"),
    (dict(case="genitive"), "вісімдесяти́"),
    (dict(case="genitive"), "вісімдесятьо́х"),
    (dict(case="dative"), "вісімдесяти́"),
    (dict(case="dative"), "вісімдесятьо́м"),
    (dict(case="accusative", animacy="inanimate"), "вісімдеся́т"),
    (dict(case="accusative", animacy="animate"), "вісімдесятьо́х"),
    (dict(case="instrumental"), "вісімдесятьма́"),
    (dict(case="instrumental"), "вісімдесятьома́"),
    (dict(case="locative"), "вісімдесяти́"),
    (dict(case="locative"), "вісімдесятьо́х"),
    (dict(case="vocative"), "вісімдеся́т"),
  ], dict()),
  "90": ([
    (dict(case="nominative"), "девʼяно́сто"),
    (dict(case="genitive"), "девʼяно́ста"),
    (dict(case="dative"), "девʼяно́ста"),
    (dict(case="accusative"), "девʼяно́сто"),
    (dict(case="instrumental"), "девʼяно́ста"),
    (dict(case="locative"), "девʼяно́ста"),
    (dict(case="vocative"), "девʼяно́сто"),
  ], dict()),
  "100": ([
    (dict(case="nominative"), "сто́"),
    (dict(case="genitive"), "ста́"),
    (dict(case="dative"), "ста́"),
    (dict(case="accusative"), "сто́"),
    (dict(case="instrumental"), "ста́"),
    (dict(case="locative"), "ста́"),
    (dict(case="vocative"), "сто́"),
  ], dict()),
  "200": ([
    (dict(case="nominative"), "дві́сті"),
    (dict(case="genitive"), "двохсо́т"),
    (dict(case="dative"), "двомста́м"),
    (dict(case="accusative"), "дві́сті"),
    (dict(case="instrumental"), "двомаста́ми"),
    (dict(case="locative"), "двохста́х"),
    (dict(case="vocative"), "дві́сті"),
  ], dict()),
  "300": ([
    (dict(case="nominative"), "три́ста"),
    (dict(case="genitive"), "трьохсо́т"),
    (dict(case="dative"), "трьомста́м"),
    (dict(case="accusative"), "три́ста"),
    (dict(case="instrumental"), "трьомаста́ми"),
    (dict(case="locative"), "трьохста́х"),
    (dict(case="vocative"), "три́ста"),
  ], dict()),
  "400": ([
    (dict(case="nominative"), "чоти́риста"),
    (dict(case="genitive"), "чотирьохсо́т"),
    (dict(case="dative"), "чотирьомста́м"),
    (dict(case="accusative"), "чоти́риста"),
    (dict(case="instrumental"), "чотирмаста́ми"),
    (dict(case="locative"), "чотирьохста́х"),
    (dict(case="vocative"), "чоти́риста"),
  ], dict()),
  "500": ([
    (dict(case="nominative"), "пʼятсо́т"),
    (dict(case="genitive"), "пʼятисо́т"),
    (dict(case="dative"), "пʼятиста́м"),
    (dict(case="accusative"), "пʼятсо́т"),
    (dict(case="instrumental"), "пʼятьмаста́ми"),
    (dict(case="instrumental"), "пʼятьомаста́ми"),
    (dict(case="locative"), "пʼятиста́х"),
    (dict(case="vocative"), "пʼятсо́т"),
  ], dict()),
  "600": ([
    (dict(case="nominative"), "шістсо́т"),
    (dict(case="genitive"), "шестисо́т"),
    (dict(case="dative"), "шестиста́м"),
    (dict(case="accusative"), "шістсо́т"),
    (dict(case="instrumental"), "шістьмаста́ми"),
    (dict(case="instrumental"), "шістьомаста́ми"),
    (dict(case="locative"), "шестиста́х"),
    (dict(case="vocative"), "шістсо́т"),
  ], dict()),
  "700": ([
    (dict(case="nominative"), "сімсо́т"),
    (dict(case="genitive"), "семисо́т"),
    (dict(case="dative"), "семиста́м"),
    (dict(case="accusative"), "сімсо́т"),
    (dict(case="instrumental"), "семиста́ми"),
    (dict(case="instrumental"), "сімомаста́ми"),
    (dict(case="locative"), "семиста́х"),
    (dict(case="vocative"), "сімсо́т"),
  ], dict()),
  "800": ([
    (dict(case="nominative"), "вісімсо́т"),
    (dict(case="genitive"), "восьмисо́т"),
    (dict(case="dative"), "восьмиста́м"),
    (dict(case="accusative"), "вісімсо́т"),
    (dict(case="instrumental"), "вісьмаста́ми"),
    (dict(case="instrumental"), "вісьмомаста́ми"),
    (dict(case="locative"), "восьмиста́х"),
    (dict(case="vocative"), "вісімсо́т"),
  ], dict()),
  "900": ([
    (dict(case="nominative"), "девʼятсо́т"),
    (dict(case="genitive"), "девʼятисо́т"),
    (dict(case="dative"), "девʼятиста́м"),
    (dict(case="accusative"), "девʼятсо́т"),
    (dict(case="instrumental"), "девʼятьмаста́ми"),
    (dict(case="instrumental"), "девʼятьомаста́ми"),
    (dict(case="locative"), "девʼятиста́х"),
    (dict(case="vocative"), "девʼятсо́т"),
  ], dict()),
  "0": ([
    (dict(case="nominative", number="singular"), "ну́ль"),
    (dict(case="genitive", number="singular"), "нуля́"),
    (dict(case="dative", number="singular"), "нулю́"),
    (dict(case="dative", number="singular"), "нуле́ві"),
    (dict(case="accusative", number="singular"), "ну́ль"),
    (dict(case="instrumental", number="singular"), "нуле́м"),
    (dict(case="locative", number="singular"), "нулі́"),
    (dict(case="locative", number="singular"), "нулю́"),
    (dict(case="vocative", number="singular"), "ну́лю"),
    (dict(case="nominative", number="plural"), "нулі́"),
    (dict(case="genitive", number="plural"), "нулі́в"),
    (dict(case="dative", number="plural"), "нуля́м"),
    (dict(case="accusative", number="plural"), "нулі́"),
    (dict(case="instrumental", number="plural"), "нуля́ми"),
    (dict(case="locative", number="plural"), "нуля́х"),
    (dict(case="vocative", number="plural"), "нулі́"),
  ], dict(gender="masculine", animacy="inanimate")),
  "1000": ([
    (dict(case="nominative", number="singular"), "ти́сяча"),
    (dict(case="nominative", number="plural"), "ти́сячі"),
    (dict(case="genitive", number="singular"), "ти́сячі"),
    (dict(case="genitive", number="plural"), "ти́сяч"),
    (dict(case="dative", number="singular"), "ти́сячі"),
    (dict(case="dative", number="plural"), "ти́сячам"),
    (dict(case="accusative", number="singular"), "ти́сячу"),
    (dict(case="accusative", number="plural"), "ти́сячі"),
    (dict(case="instrumental", number="singular"), "ти́сячею"),
    (dict(case="instrumental", number="plural"), "ти́сячами"),
    (dict(case="locative", number="singular"), "ти́сячі"),
    (dict(case="locative", number="plural"), "ти́сячах"),
    (dict(case="vocative", number="singular"), "ти́сяче"),
    (dict(case="vocative", number="plural"), "ти́сячі"),
  ], dict(gender="feminine", animacy="inanimate")),
  "1000000": ([
    (dict(case="nominative", number="singular"), "мільйо́н"),
    (dict(case="nominative", number="plural"), "мільйо́ни"),
    (dict(case="genitive", number="singular"), "мільйо́на"),
    (dict(case="genitive", number="plural"), "мільйо́нів"),
    (dict(case="dative", number="singular"), "мільйо́ну"),
    (dict(case="dative", number="singular"), "мільйо́нові"),
    (dict(case="dative", number="plural"), "мільйо́нам"),
    (dict(case="accusative", number="singular"), "мільйо́н"),
    (dict(case="accusative", number="plural"), "мільйо́ни"),
    (dict(case="instrumental", number="singular"), "мільйо́ном"),
    (dict(case="instrumental", number="plural"), "мільйо́нами"),
    (dict(case="locative", number="singular"), "мільйо́ні"),
    (dict(case="locative", number="plural"), "мільйо́нах"),
    (dict(case="vocative", number="singular"), "мільйо́не"),
    (dict(case="vocative", number="plural"), "мільйо́ни"),
  ], dict(gender="masculine", animacy="inanimate")),
  "1000000000": ([
    (dict(case="nominative", number="singular"), "мілья́рд"),
    (dict(case="nominative", number="plural"), "мілья́рди"),
    (dict(case="genitive", number="singular"), "мілья́рда"),
    (dict(case="genitive", number="plural"), "мілья́рдів"),
    (dict(case="dative", number="singular"), "мілья́рду"),
    (dict(case="dative", number="singular"), "мілья́рдові"),
    (dict(case="dative", number="plural"), "мілья́рдам"),
    (dict(case="accusative", number="singular"), "мілья́рд"),
    (dict(case="accusative", number="plural"), "мілья́рди"),
    (dict(case="instrumental", number="singular"), "мілья́рдом"),
    (dict(case="instrumental", number="plural"), "мілья́рдами"),
    (dict(case="locative", number="singular"), "мілья́рді"),
    (dict(case="locative", number="plural"), "мілья́рдах"),
    (dict(case="vocative", number="singular"), "мілья́рде"),
    (dict(case="vocative", number="plural"), "мілья́рди"),
  ], dict(gender="masculine", animacy="inanimate")),
  "1000000000000": ([
    (dict(case="nominative", number="singular"), "трильйо́н"),
    (dict(case="nominative", number="plural"), "трильйо́ни"),
    (dict(case="genitive", number="singular"), "трильйо́на"),
    (dict(case="genitive", number="plural"), "трильйо́нів"),
    (dict(case="dative", number="singular"), "трильйо́ну"),
    (dict(case="dative", number="singular"), "трильйо́нові"),
    (dict(case="dative", number="plural"), "трильйо́нам"),
    (dict(case="accusative", number="singular"), "трильйо́н"),
    (dict(case="accusative", number="plural"), "трильйо́ни"),
    (dict(case="instrumental", number="singular"), "трильйо́ном"),
    (dict(case="instrumental", number="plural"), "трильйо́нами"),
    (dict(case="locative", number="singular"), "трильйо́ні"),
    (dict(case="locative", number="plural"), "трильйо́нах"),
    (dict(case="vocative", number="singular"), "трильйо́не"),
    (dict(case="vocative", number="plural"), "трильйо́ни"),
  ], dict(gender="masculine", animacy="inanimate")),
  "1000000000000000": ([
    (dict(case="nominative", number="singular"), "квадрильйо́н"),
    (dict(case="nominative", number="plural"), "квадрильйо́ни"),
    (dict(case="genitive", number="singular"), "квадрильйо́на"),
    (dict(case="genitive", number="plural"), "квадрильйо́нів"),
    (dict(case="dative", number="singular"), "квадрильйо́ну"),
    (dict(case="dative", number="singular"), "квадрильйо́нові"),
    (dict(case="dative", number="plural"), "квадрильйо́нам"),
    (dict(case="accusative", number="singular"), "квадрильйо́н"),
    (dict(case="accusative", number="plural"), "квадрильйо́ни"),
    (dict(case="instrumental", number="singular"), "квадрильйо́ном"),
    (dict(case="instrumental", number="plural"), "квадрильйо́нами"),
    (dict(case="locative", number="singular"), "квадрильйо́ні"),
    (dict(case="locative", number="plural"), "квадрильйо́нах"),
    (dict(case="vocative", number="singular"), "квадрильйо́не"),
    (dict(case="vocative", number="plural"), "квадрильйо́ни"),
  ], dict(gender="masculine", animacy="inanimate")),
  "1000000000000000000": ([
    (dict(case="nominative", number="singular"), "квінтильйо́н"),
    (dict(case="nominative", number="plural"), "квінтильйо́ни"),
    (dict(case="genitive", number="singular"), "квінтильйо́на"),
    (dict(case="genitive", number="plural"), "квінтильйо́нів"),
    (dict(case="dative", number="singular"), "квінтильйо́ну"),
    (dict(case="dative", number="singular"), "квінтильйо́нові"),
    (dict(case="dative", number="plural"), "квінтильйо́нам"),
    (dict(case="accusative", number="singular"), "квінтильйо́н"),
    (dict(case="accusative", number="plural"), "квінтильйо́ни"),
    (dict(case="instrumental", number="singular"), "квінтильйо́ном"),
    (dict(case="instrumental", number="plural"), "квінтильйо́нами"),
    (dict(case="locative", number="singular"), "квінтильйо́ні"),
    (dict(case="locative", number="plural"), "квінтильйо́нах"),
    (dict(case="vocative", number="singular"), "квінтильйо́не"),
    (dict(case="vocative", number="plural"), "квінтильйо́ни"),
  ], dict(gender="masculine", animacy="inanimate")),
  "1000000000000000000000": ([
    (dict(case="nominative", number="singular"), "секстильйо́н"),
    (dict(case="nominative", number="plural"), "секстильйо́ни"),
    (dict(case="genitive", number="singular"), "секстильйо́на"),
    (dict(case="genitive", number="plural"), "секстильйо́нів"),
    (dict(case="dative", number="singular"), "секстильйо́ну"),
    (dict(case="dative", number="singular"), "секстильйо́нові"),
    (dict(case="dative", number="plural"), "секстильйо́нам"),
    (dict(case="accusative", number="singular"), "секстильйо́н"),
    (dict(case="accusative", number="plural"), "секстильйо́ни"),
    (dict(case="instrumental", number="singular"), "секстильйо́ном"),
    (dict(case="instrumental", number="plural"), "секстильйо́нами"),
    (dict(case="locative", number="singular"), "секстильйо́ні"),
    (dict(case="locative", number="plural"), "секстильйо́нах"),
    (dict(case="vocative", number="singular"), "секстильйо́не"),
    (dict(case="vocative", number="plural"), "секстильйо́ни"),
  ], dict(gender="masculine", animacy="inanimate")),
  "1000000000000000000000000": ([
    (dict(case="nominative", number="singular"), "септильйо́н"),
    (dict(case="nominative", number="plural"), "септильйо́ни"),
    (dict(case="genitive", number="singular"), "септильйо́на"),
    (dict(case="genitive", number="plural"), "септильйо́нів"),
    (dict(case="dative", number="singular"), "септильйо́ну"),
    (dict(case="dative", number="singular"), "септильйо́нові"),
    (dict(case="dative", number="plural"), "септильйо́нам"),
    (dict(case="accusative", number="singular"), "септильйо́н"),
    (dict(case="accusative", number="plural"), "септильйо́ни"),
    (dict(case="instrumental", number="singular"), "септильйо́ном"),
    (dict(case="instrumental", number="plural"), "септильйо́нами"),
    (dict(case="locative", number="singular"), "септильйо́ні"),
    (dict(case="locative", number="plural"), "септильйо́нах"),
    (dict(case="vocative", number="singular"), "септильйо́не"),
    (dict(case="vocative", number="plural"), "септильйо́ни"),
  ], dict(gender="masculine", animacy="inanimate")),
}



from enum import Enum
from typing import TypedDict, Optional

__all__ = [
    "Case",
    "Gender",
    "Number",
    "Animacy",
    "InflectionForm",
    "default_inflection_form",
]


class _StrEnum(str, Enum):
    def __str__(self):  # pragma: no cover
        return self.value


class Case(_StrEnum):
    nominative = "nominative"
    genitive = "genitive"
    dative = "dative"
    accusative = "accusative"
    instrumental = "instrumental"
    locative = "locative"
    vocative = "vocative"


class Gender(_StrEnum):
    masculine = "masculine"
    feminine = "feminine"
    neuter = "neuter"
    common = "common"


class Number(_StrEnum):
    singular = "singular"
    plural = "plural"


class Animacy(_StrEnum):
    inanimate = "inanimate"
    animate = "animate"


class InflectionForm(TypedDict):
    case: Optional["Case"]
    gender: Optional["Gender"]
    number: Optional["Number"]
    animacy: Optional["Animacy"]


def default_inflection_form():
    return InflectionForm(
        case=Case.nominative,
        gender=Gender.masculine,
        number=Number.singular,
        animacy=Animacy.inanimate,
    )
